@@ -10,6 +10,8 @@ from magicapi.Models.task_executor import save_tasks
 
 from magicapi.Services.Sentry import HAS_SENTRY_DSN, capture_exception
 
+from magicapi.Errors import IgnoreException
+
 
 class MagicCallLogger(APIRoute):
     def get_route_handler(self) -> Callable:
@@ -21,6 +23,8 @@ class MagicCallLogger(APIRoute):
             time_received = datetime.utcnow()
             try:
                 response: Response = await original_route_handler(request)
+            except IgnoreException:
+                pass
             except Exception as e:
                 if HAS_SENTRY_DSN:
                     capture_exception(e)
